@@ -115,7 +115,7 @@ class Session:
                 d = auth_response.read()
                 j = json.loads(d)
                 auth_status = j.get('authentication_status')
-                self.session_status = auth_status['session_status']
+                self.session_status = Status[auth_status['session_status']]
                 return self.session_status
         except HTTPError as ex:
             logger.warning("get status failed {}".format(ex))
